MacosFrameExt

Trait MacosFrameExt 

pub trait MacosFrameExt {
    // Required method
    fn pixel_buffer(&self) -> &CVPixelBuffer;
}
Available on crate feature std and macOS only.
macOS-specific frame data.

Required Methods

fn pixel_buffer(&self) -> &CVPixelBuffer

Access the underlying CVPixelBuffer.

The buffer is valid for the lifetime of the frame (i.e. the callback scope). To keep it alive longer, retain it with CFRetained::retain(pixel_buffer).

Implementors